{% extends 'leprikon/default.html' %}

{% block content %}

<h1>{% block title %}{{ title }}{% endblock %}</h1>

{% for error in form.non_field_errors %}
    <p>{{ error }}</p>
{% endfor %}

{% include 'leprikon/form.html' %}

{% endblock %}
